@@ -7,7 +7,7 @@ use Archive::Har::Entry::Cookie();
 use Archive::Har::Entry::Request::QueryString();
 use Archive::Har::Entry::Request::PostData();
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 sub new {
 	my ($class, $params) = @_;
@@ -59,7 +59,7 @@ sub method {
 	my ($self, $new) = @_;
 	my $old = $self->{method};
 	if (@_ > 1) {
-		$self->{method} = uc $new;
+		$self->{method} = defined $new ? uc $new : $new;
 	}
 	if (defined $old) {
 		return $old;
@@ -85,7 +85,7 @@ sub http_version {
 	my ($self, $new) = @_;
 	my $old = $self->{httpVersion};
 	if (@_ > 1) {
-		$self->{httpVersion} = uc $new;
+		$self->{httpVersion} = defined $new ? uc $new : $new;
 	}
 	if (defined $old) {
 		return $old;
@@ -249,7 +249,7 @@ Archive::Har::Entry::Request - Represents a single http request inside the HTTP
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =head1 SYNOPSIS
 
