@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Archive::Har::Entry::Request::PostData::Params();
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 sub new {
 	my ($class, $params) = @_;
@@ -83,7 +83,7 @@ sub comment {
 sub AUTOLOAD {
 	my ($self, $new) = @_;
 
-	my $name = $Archive::Har::Page::PageTimings::AUTOLOAD;
+	my $name = $Archive::Har::Entry::Request::PostData::AUTOLOAD;
 	$name =~ s/.*://smx;   # strip fully-qualified portion
 
 	my $old;
@@ -128,7 +128,7 @@ Archive::Har::Entry::Request::PostData - Represents a single name/value pair fro
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =head1 SYNOPSIS
 
