@@ -5,7 +5,7 @@ use strict;
 use Carp();
 use Archive::Har::Entry::Cache::Request();
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 sub new {
 	my ($class, $params) = @_;
@@ -44,12 +44,12 @@ sub blocked {
 	my $old = $self->{blocked};
 	if (@_ > 1) {
 		if (defined $new) {
-			$self->{blocked} = $new;
+			$self->{blocked} = $new + 0;
 		} else {
-			$self->{blocked} = '-1';
+			$self->{blocked} = -1;
 		}
 	}
-	if ((defined $old) && ($old eq '-1')) {
+	if ((defined $old) && ($old eq -1)) {
 		return;
 	} else {
 		return $old;
@@ -61,12 +61,12 @@ sub dns {
 	my $old = $self->{dns};
 	if (@_ > 1) {
 		if (defined $new) {
-			$self->{dns} = $new;
+			$self->{dns} = $new + 0;
 		} else {
-			$self->{dns} = '-1';
+			$self->{dns} = -1;
 		}
 	}
-	if ((defined $old) && ($old eq '-1')) {
+	if ((defined $old) && ($old eq -1)) {
 		return;
 	} else {
 		return $old;
@@ -78,12 +78,12 @@ sub connect {
 	my $old = $self->{connect};
 	if (@_ > 1) {
 		if (defined $new) {
-			$self->{connect} = $new;
+			$self->{connect} = $new + 0;
 		} else {
-			$self->{connect} = '-1';
+			$self->{connect} = -1;
 		}
 	}
-	if ((defined $old) && ($old eq '-1')) {
+	if ((defined $old) && ($old eq -1)) {
 		return;
 	} else {
 		return $old;
@@ -94,7 +94,7 @@ sub send {
 	my ($self, $new) = @_;
 	my $old = $self->{send};
 	if (@_ > 1) {
-		$self->{send} = $new;
+		$self->{send} = $new + 0;
 	}
 	return $old;
 }
@@ -103,7 +103,7 @@ sub wait {
 	my ($self, $new) = @_;
 	my $old = $self->{wait};
 	if (@_ > 1) {
-		$self->{wait} = $new;
+		$self->{wait} = $new + 0;
 	}
 	return $old;
 }
@@ -112,7 +112,7 @@ sub receive {
 	my ($self, $new) = @_;
 	my $old = $self->{receive};
 	if (@_ > 1) {
-		$self->{receive} = $new;
+		$self->{receive} = $new + 0;
 	}
 	return $old;
 }
@@ -122,12 +122,12 @@ sub ssl {
 	my $old = $self->{ssl};
 	if (@_ > 1) {
 		if (defined $new) {
-			$self->{ssl} = $new;
+			$self->{ssl} = $new + 0;
 		} else {
-			$self->{ssl} = '-1';
+			$self->{ssl} = -1;
 		}
 	}
-	if ((defined $old) && ($old eq '-1')) {
+	if ((defined $old) && ($old eq -1)) {
 		return;
 	} else {
 		return $old;
@@ -211,7 +211,7 @@ Archive::Har::Entry::Timings - Represents the timings for the individual phases
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =head1 SYNOPSIS
 
